|
Fortran vs Julia stack allocated arrays
|
|
18
|
6889
|
November 29, 2018
|
|
Memoization of functions with vector inputs in Julia and JuMP
|
|
0
|
495
|
November 29, 2018
|
|
Achieving C++ Speeds for a CFD Algorithm: Julia spends too much time on pre-allocation?
|
|
22
|
4019
|
November 28, 2018
|
|
Sparse array problem: is this a known bug?
|
|
6
|
815
|
November 27, 2018
|
|
GLM is slow on large datasets. Using OnlineStats for regressions? MixedModels?
|
|
25
|
5540
|
November 26, 2018
|
|
Behavior of worker pool in pmap
|
|
2
|
962
|
November 25, 2018
|
|
Compilation performance. Branching
|
|
3
|
1081
|
November 25, 2018
|
|
Sluggish performance when loading in modules DataFrames, CSV
|
|
0
|
456
|
November 22, 2018
|
|
Small benchmark
|
|
14
|
3147
|
November 21, 2018
|
|
Macro hygiene in nested quote not working
|
|
11
|
1454
|
November 21, 2018
|
|
Problems Installing Julia and MKL OSX
|
|
6
|
1660
|
November 19, 2018
|
|
Building Julia: Does the compiler matter?
|
|
3
|
1864
|
November 19, 2018
|
|
Source code from "Julia: Dynamism and Performance Reconciled by Design"?
|
|
4
|
978
|
November 19, 2018
|
|
Migrating code from Matlab: Accessing arrays without allocating
|
|
20
|
2246
|
November 19, 2018
|
|
Help reduce large gc time
|
|
32
|
4123
|
November 18, 2018
|
|
Reassigning variable in do syntax is not optimized, ``Ref`` is, what is the difference?
|
|
1
|
550
|
November 17, 2018
|
|
Is this a valid @pure function?
|
|
3
|
739
|
November 16, 2018
|
|
When does julia infer optimal code, when not?
|
|
4
|
787
|
November 16, 2018
|
|
Is there way to avoid `materialize` and `copy`?
|
|
20
|
3591
|
November 15, 2018
|
|
Help Optimizing Slow Distributed Array Computation
|
|
7
|
2060
|
November 14, 2018
|
|
Array views becoming dominant source of memory allocation
|
|
31
|
5711
|
November 14, 2018
|
|
Could the usage of `haskey` be unidiomatic/inefficient?
|
|
6
|
1414
|
November 13, 2018
|
|
Does GC overhead scale with memory consumption?
|
|
4
|
900
|
November 12, 2018
|
|
Allocations when manipulating an iterator
|
|
5
|
865
|
November 12, 2018
|
|
Help with optimizing GC time with large objects in memory
|
|
3
|
750
|
November 10, 2018
|
|
Stdin/stdout 10x slower than file open
|
|
13
|
4602
|
November 9, 2018
|
|
Pairwise distance using matrix or Vector{SVector}: The first is faster!
|
|
4
|
1424
|
November 8, 2018
|
|
Inlining behavior: constant prop. fails, I need help in understanding "why"
|
|
9
|
1216
|
November 8, 2018
|
|
Is constructing an array on the fly on this line costing me a lot of memory?
|
|
9
|
980
|
November 8, 2018
|
|
When I import Gtk library my code became immaediately slower
|
|
2
|
594
|
November 8, 2018
|